import proxify from "event-target-proxy/index.mjs";
import { StdOutError, StdErrError } from "./error-classes.mjs";
import fromEventedStream from "./from-evented-stream.mjs";
export function fromChildProcess(cp) {
  const {
    stdout,
    stderr
  } = cp;
  const proxifiedStdOut = proxify(stdout, ({
    event,
    listener
  }) => event === 'error' ? error => listener(new StdOutError(stdout, error)) : listener);
  const proxifiedStdErr = proxify(stderr, ({
    event,
    listener
  }) => event === 'error' ? error => listener(new StdErrError(stderr, error)) : listener);

  const createEvtMod = modfn => (event, fn) => {
    switch (event) {
      case 'close':
        modfn(cp, 'close', fn);
        break;

      case 'error':
        modfn(cp, 'error', fn);
        modfn(proxifiedStdOut, 'error', fn);
        modfn(proxifiedStdErr, 'error', fn);
        break;

      case 'data':
        modfn(proxifiedStdOut, 'data', fn);
        modfn(proxifiedStdErr, 'data', fn);
        break;
    }
  };

  const addListener = createEvtMod((target, event, fn) => target.addListener(event, fn));
  const removeListener = createEvtMod((target, event, fn) => target.removeListener(event, fn));
  return fromEventedStream({
    addListener,
    removeListener
  });
}
export default fromChildProcess; //# sourceMappingURL=from-child-process.js.map